import { Component, ViewChild } from '@angular/core';
import { EJComponents } from 'ej-angular2';
@Component({
    selector: 'ej-app',
    templateUrl: './grid.component.html',
})
export class GridComponent {
    // Component references
    @ViewChild('myGridComponent') myGrid: EJComponents<ej.Grid, any>;
    @ViewChild('myListComponent') myList: EJComponents<ej.DropDownList, any>;

    // Grid 
    private gridData: ej.DataManager = new ej.DataManager({ url: "http://js.syncfusion.com/demos/ejServices/Wcf/Northwind.svc/Orders", crossDomain: true });
    private filterSettings: ej.Grid.FilterSettings = { filterBarMode: ej.Grid.FilterBarMode.OnEnter, filterType: ej.Grid.FilterType.Excel };

    // DropdownList
    private dropDownListSelectedValue;
    private dropDownListDataList : Array<Object> = [{ text: "State 1", value: 1 }, { text: "State 2", value: 2 }, { text: "State 3", value: 3 }, { text: "State 4", value: 4 }, { text: "State 5", value: 5 }];
    private dropDrownListField = { dataSource: this.dropDownListDataList, text: "text", value: "value" };        

    // State
    private states = {};
    private state1 : string;
    private state2 : string;
    private state3 : string;
    private state4 : string;
    private state5 : string;

    // Constructor
    constructor() {}

    // Load and set state
    private onLoadStateClicked(args) 
    {
        // Getting grid widget
        var grid = this.myGrid.widget;

        // Creating state object
        var state = JSON.parse(this.getStateString());

         // Setting filters
         grid.model.filterSettings.filteredColumns = state.filteredColumns.slice();
         grid.model.sortSettings.sortedColumns = state.sortedColumns.slice();
         grid.model.searchSettings = state.searchSettings;
         grid.model.columns = state.columns.slice();
         grid.model.groupSettings.groupedColumns = state.groupedColumns.slice();
         
         // Refreshing columns
         grid.columns(state.columns.slice());

        console.log('State loaded with id: ' + this.dropDownListSelectedValue + ', state: ', state);        
    }

    // Save state
    private onSaveStateClicked(args)
    {
        // Getting grid widget
        var grid = this.myGrid.widget;
        
        // Creating state object
        var state = {
            columns: grid.model.columns.slice(),
            groupedColumns: grid.model.groupSettings.groupedColumns.slice(),
            filteredColumns: grid.model.filterSettings.filteredColumns.slice(),
            sortedColumns: grid.model.sortSettings.sortedColumns.slice(),
            searchSettings: grid.model.searchSettings
        }

        // Converting json to string
        var stateString = JSON.stringify(state);

        // Saving state
        this.setStateString(stateString);
        
        console.log('State saved with id: ' + this.dropDownListSelectedValue + ', state: ', state);
    }


    private getStateString() : string
    {
        var stateString : string;
        
        if (this.dropDownListSelectedValue == 1)
            stateString = this.state1;
        else if (this.dropDownListSelectedValue == 2)
            stateString = this.state2;
        else if (this.dropDownListSelectedValue == 3)
            stateString = this.state3;        
        else if (this.dropDownListSelectedValue == 4)
            stateString = this.state4; 
        else
            stateString = this.state5; 

        return stateString;
    }

    private setStateString(stateString : string) : void
    {
        if (this.dropDownListSelectedValue == 1)
            this.state1 = stateString;
        else if (this.dropDownListSelectedValue == 2)
            this.state2 = stateString;
        else if (this.dropDownListSelectedValue == 3)
            this.state3 = stateString;        
        else if (this.dropDownListSelectedValue == 4)
            this.state4 = stateString; 
        else
            this.state5 = stateString; 
    }

}
